package services.as400Connector.server;

import javax.naming.NamingException;
import javax.naming.Reference;
import javax.resource.ResourceException;
import javax.resource.spi.ConnectionManager;

import services.as400Connector.client.AS400Connection;
import services.as400Connector.client.AS400ConnectionFactory;

/**
 * must implement Serializable and Referenceable - spec 6.5.1.3
 * @author eduardp
 *
 */
public class AS400ConnectionFactoryImpl implements AS400ConnectionFactory {

  private static final long serialVersionUID = 1L;

  private Reference reference;
  private ConnectionManager cxManager;
  private AS400ManagedConnectionFactory mcf; //my creator
  
  public AS400ConnectionFactoryImpl(AS400ManagedConnectionFactory mcf, ConnectionManager cxManager) {
    
    this.mcf       = mcf;
    this.cxManager = cxManager;
    
  }

  /**
   * This method can also take as parameters client request specific parameters that are passed on as ConnectionRequestInfo in allocateConnection
   */
  public AS400Connection getConnection() {
    mcf.getLogger().info("Processing new client request for connection");
    try {
      return (AS400Connection) cxManager.allocateConnection(mcf, null);
    } catch (ResourceException e) {
      throw new RuntimeException("Could not get connection",e);
    }
    
  }

  /**
   * required by spec
   */
  public void setReference(Reference reference) {
    this.reference = reference;
  }

  /**
   * required by spec
   */
  public Reference getReference() throws NamingException {
    return reference;
  }

}
