package services.as400Connector.server;

import libraries.ejbUtils.logging.Logger;
import services.as400Connector.client.AS400Connection;

import com.ibm.as400.access.AS400;
import com.ibm.as400.data.PcmlException;
import com.ibm.as400.data.ProgramCallDocument;

public class AS400ConnectionImpl implements AS400Connection {

  private AS400ManagedConnection managedCx;
  private Logger log;
  
  public AS400ConnectionImpl(AS400ManagedConnection managedCx) {
    this.managedCx = managedCx;
    this.log       = managedCx.getLogger();
  }
  
  public void close() {
    log.info("Client called close on connection, invalidating the handle"); 
    if (managedCx == null) {
      return;
    }
    
    managedCx.removeCxHandle(this);
    
    managedCx.closeCxHandle(this);
    
    invalidate();
  }
  
  void invalidate() {
    log.info("Invalidating the managed connection");
    managedCx = null;
  }
  
  void checkIfValid() {
    if (managedCx == null) {
      throw new RuntimeException("This connection is no longer valid");
    }
  }

  public ProgramCallDocument createProgramCallDocument(String pcmlFile) {
//    log.info("Client creates new ProgramCallDocument for pcml file : " + pcmlFile);
//    try {
      return null; //new ProgramCallDocument(getAS400System(),pcmlFile);
//    } catch (PcmlException e) {
//      log.error("Failed to create new ProgramCallDocument",e);
//      throw new RuntimeException("Failed to create ProgramCallDocument",e);
//    }
  }
  
  public boolean executeProgramCallDocument(ProgramCallDocument pcd, String programName) {
    String isTransactional = (managedCx.isInTransaction() ? "N" : "Y");
    log.info("Client executes ProgramCallDocument. programName= " + programName + ", transactional = " + isTransactional);
    try {
      pcd.setValue(programName + ".DataBase", managedCx.getDatabase());
      pcd.setValue(programName + ".userName", managedCx.getUsername());
      
      pcd.setValue(programName + ".moreRecsOrCommit", isTransactional);
      return pcd.callProgram(programName);
    } catch (PcmlException e) {
      log.error("Failed to execute ProgramCallDocument",e);
      managedCx.notifyConnectionError();
      throw new RuntimeException("Failed to execute ProgramCallDocument for program '" + programName + "'",e);
    }
  }

  void associateConnection(AS400ManagedConnection newManagedCx) {
    log.info("Making new connection association");
    checkIfValid();
    newManagedCx.addCxHandle(this);
    managedCx.removeCxHandle(this);
    managedCx = newManagedCx;
  }
  
  private AS400 getAS400System() {
    checkIfValid();
    return managedCx.getAS400System();
  }
  
  public String toString() {
    return super.toString() + ";managed cx: " + managedCx.toString();
  }

}
