package services.configurationConnector.server;

import javax.naming.NamingException;
import javax.naming.Reference;
import javax.resource.ResourceException;
import javax.resource.spi.ConnectionManager;
import javax.resource.spi.ConnectionRequestInfo;

import services.configurationConnector.client.ConfigurationConnection;
import services.configurationConnector.client.ConfigurationConnectionFactory;
import services.configurationConnector.client.InvalidModuleException;

/**
 * must implement Serializable and Referenceable - spec 6.5.1.3
 * @author eduardp
 *
 */
public class ConfigurationConnectionFactoryImpl implements ConfigurationConnectionFactory {
  
  private static final long serialVersionUID = 1L;

  private Reference reference;
  private ConnectionManager cxManager;
  private ConfigurationManagedConnectionFactory mcf; //my creator
  
  public ConfigurationConnectionFactoryImpl(ConfigurationManagedConnectionFactory mcf, ConnectionManager cxManager) {
    this.mcf       = mcf;
    this.cxManager = cxManager;
  }
  
  public ConfigurationConnection getConnection(String module) throws InvalidModuleException {
    try {
      return (ConfigurationConnection) cxManager.allocateConnection(mcf, new ConfigurationConnectionRequestInfo(module));
    } catch (ResourceException e) {
      throw new RuntimeException("Could not get connection",e);
    }
  }

  /**
   * required by spec
   */
  public Reference getReference() {
    return reference;
  }

  /**
   * required by spec
   */
  public void setReference(Reference reference) {
    this.reference = reference;
  }

  
}
