package services.configurationConnector.server;

import java.util.Properties;

import libraries.configuration.ConfigurationService;
import libraries.ejbUtils.logging.Logger;

import services.configurationConnector.client.ConfigurationConnection;
import services.configurationConnector.client.MissingPropertyException;

public class ConfigurationConnectionImpl implements ConfigurationConnection {

  private ConfigurationManagedConnection managedCx;
  private ConfigurationService configurationService;
  private String module;
  
  public ConfigurationConnectionImpl(ConfigurationManagedConnection managedCx) {
    this.managedCx            = managedCx;
    this.configurationService = managedCx.getConfigurationService();
    this.module               = managedCx.getModule();
  }
  
  public void close() {
    if (managedCx == null) {
      return;
    }
    managedCx.removeCxHandle(this);
    managedCx.closeCxHandle(this);
    invalidate();
  }

  void invalidate() {
    managedCx = null;
  }

  void checkIfValid() {
    if (managedCx == null) {
      throw new RuntimeException("This connection is no longer valid");
    }
  }
  
  public void flushCache() {
    configurationService.flushModuleCache(module);
  }

  public String getMandatoryProperty(String name) throws MissingPropertyException {
    return configurationService.getMandatoryProperty(module, name);
  }

  public Properties getModuleProperties() {
    return configurationService.getModuleProperties(module);
  }

  public String getProperty(String name) {
    return configurationService.getProperty(module, name);
  }

  public String getProperty(String name, String defaultValue) {
    return configurationService.getProperty(module, name, defaultValue);
  }

  public void setModuleTimout(long timeoutMillis) {
    configurationService.setModuleTimout(module, timeoutMillis);
  }
  
  void associateConnection(ConfigurationManagedConnection newManagedCx) {
    checkIfValid();
    newManagedCx.addCxHandle(this);
    managedCx.removeCxHandle(this);
    managedCx = newManagedCx;
  }

  
  public Logger getLogger() {
    return managedCx.getLogger();  
  }

}
