package libraries.ejbUtils.logging;

/**
 * Use the loggingService class to get a reference to a Logger
 * The logger interface is configured through properties. See ContextService for where properties should be stored. Here are example properties
 * All properties are required except for maxIndex and maxFileSize when useRollingLog = false
 *  
 * services.orbit.server.log.pattern=%d %-5p %-17c{2} %t - %m\n
 * services.orbit.server.log.useRollingLog=true
 * services.orbit.server.log.filename=/home/eduardp/tmp/orbitLog.log
 * services.orbit.server.log.level=debug
 * services.orbit.server.log.maxIndex=10
 * services.orbit.server.log.maxFileSize=1MB
 * 
 * @author eduardp
 *
 */
public interface Logger {

  void debug(Object message);
  void debug(Object message, Throwable t);
  
  void info(Object message);
  void info(Object message, Throwable t);
  
  void warn(Object message);
  void warn(Object message, Throwable t);
  
  void error(Object message);
  void error(Object message, Throwable t);
  
  void fatal(Object message);
  void fatal(Object message, Throwable t);
  
  Level getLevel();
  
  boolean isDebugEnabled();
  
  boolean isInfoEnabled();
  
  boolean isEnabledFor(Level level);
  
}
