package libraries.ejbUtils.logging;

import java.util.Properties;

/**
 * Returns a reference to a logger.
 * Current implementation is for log4j
 * Properties are typically retrieved using the configuration ejb.
 * You have to provide a name for the log, that is unique across all loggers in the app server. Normally you would use the name of your module eg. services.orbit.server
 * You can also provide a different log name, for example if you want each ejb to log to a different logfile, then provide a unique logname for each ejb eg. services.orbit.server.person and services.orbit.server.group
 * 
 * In it's current implementation, if a call is made to return a logger and the logger has already been configured, it will be reconfigured. 
 * This means that if the properties of the logger are not going to change, it would be best for the calling program to store a reference to the Logger.
 * A static variable or JCA connector might be best for this
 *     
 * @author eduardp
 *
 */
public class LoggingService {

  /**
   * Returns a logger. Use the default property prefix called 'logger' when looking for log properties. This is useful when your module uses the global logging configuration
   * @param logName - the name of the log to use
   * @param props - the properties used to configure the log
   * @return - a configured logger
   */
  public static Logger getLogger(String logName,Properties props) {
    return new Log4jLogger(logName,props);
  }
  
  /**
   * Returns a logger. Use the given property prefix when looking for log properties. This is useful when your module has it's own logging configuration
   * @param logName - the name of the log to use
   * @param props - the properties used to configure the log
   * @return - a configured logger
   */
  public static Logger getLogger(String logName,String propertyPrefix,Properties props) {
    return new Log4jLogger(logName,propertyPrefix,props);
  }
  
}
